==> kate-debuginfo-17.04.3-2.tar.xz: usr/src/debug/kate-17.04.3-2/kwrite/qrc_kwrite.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.6.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/kate/kate-17.04.3-2.i686/src/kate-17.04.3/kwrite/data/kwriteui.rc
  0x0,0x0,0x2,0x7c,
  0x0,
  0x0,0xa,0x3e,0x78,0x9c,0x9d,0x56,0x4d,0x8f,0x9b,0x30,0x10,0xbd,0xef,0xaf,0x70,
  0x39,0xf4,0xc6,0xd2,0x95,0x2a,0xb5,0x6a,0x48,0x56,0x6d,0x37,0xdb,0xbd,0x44,0x5d,
  0x29,0xd9,0x4a,0x7b,0x42,0xe,0x4c,0x12,0x2b,0x60,0xbb,0xb6,0x49,0x56,0xfd,0xf5,
  0x1d,0x1b,0x92,0x10,0x60,0x81,0xe4,0x6,0xe3,0xf7,0xde,0x8c,0xe7,0xc3,0x76,0x78,
  0xff,0x96,0xa5,0x64,0x7,0x4a,0x33,0xc1,0xc7,0xde,0xdd,0xed,0x27,0x8f,0x0,0x8f,
  0x45,0xc2,0xf8,0x7a,0xec,0xbd,0x2c,0x1e,0xfd,0xaf,0xde,0xfd,0xe4,0x26,0xfc,0xf0,
  0xf0,0xfb,0xe7,0xe2,0xf5,0x79,0x4a,0xb6,0x92,0x2a,0xb3,0xce,0x19,0x99,0xbf,0xce,
  0x17,0xd3,0x19,0xf1,0xe,0x86,0xdb,0xc4,0x24,0x1e,0x22,0x8f,0x0,0x4e,0x33,0x18,
  0x7b,0xdb,0xbd,0x62,0x6,0xbc,0x8a,0x8b,0x2f,0x88,0x22,0x24,0x9c,0x1,0xcf,0x7f,
  0x50,0x65,0xbf,0xcb,0xbf,0x92,0xb1,0x62,0x29,0xe2,0xb9,0x98,0x81,0x5a,0xe3,0xef,
  0x9d,0x57,0x40,0x10,0x64,0xe0,0xcd,0x4c,0x3e,0xd2,0x4c,0x8e,0x1e,0x11,0x13,0x6,
  0xee,0xff,0xb0,0xf8,0x3d,0x36,0xa8,0x5f,0xd1,0x88,0x38,0xec,0xbd,0xe0,0xb8,0x3e,
  0x7,0xc,0x8c,0x1a,0xa1,0x82,0xe,0x8a,0x90,0xc0,0xbd,0x3e,0x40,0xa4,0x20,0x6,
  0x6e,0xba,0xb5,0x1f,0x60,0xc5,0x38,0xfc,0x52,0x22,0x97,0x25,0x5f,0xd3,0x1d,0x44,
  0x99,0xdd,0x94,0x47,0xa8,0x44,0x9d,0xe4,0xcc,0x76,0xa1,0x9a,0x2,0xcc,0xa8,0xa9,
  0xeb,0x9d,0x59,0xbb,0xe8,0x52,0x31,0xde,0x60,0x57,0x8d,0x17,0x26,0x2e,0x4e,0x85,
  0xee,0xf6,0xe8,0x10,0x75,0x8f,0x55,0xe3,0x85,0x1e,0xff,0xe6,0xec,0x58,0x82,0x30,
  0xb0,0xfd,0xd3,0x6c,0x25,0x48,0x10,0xd3,0xd3,0x4a,0x53,0xc4,0xd4,0x5a,0xa9,0x19,
  0xbc,0x15,0x8a,0x72,0x9e,0x88,0xeb,0x8a,0xe5,0xe8,0x92,0x6a,0x73,0x65,0xb1,0x1d,
  0x5f,0x43,0xa,0xf1,0xa0,0xf2,0xbc,0x23,0x80,0xc6,0x64,0x8,0xdd,0x65,0xab,0x27,
  0xb3,0x3b,0x86,0xc3,0xd5,0x93,0xd9,0x3f,0x88,0xe9,0x1a,0x52,0xab,0x61,0x87,0x34,
  0x72,0x62,0x17,0xee,0xc8,0x91,0x71,0x1a,0x11,0x88,0x8a,0xba,0xaf,0x13,0x8c,0x10,
  0xa9,0xee,0xb,0x78,0x61,0x41,0xbd,0xbd,0xe0,0xa4,0xfa,0x5d,0x57,0x72,0x58,0x89,
  0x43,0x83,0x31,0x78,0xb4,0xea,0x36,0xf7,0xf3,0x72,0xad,0x16,0x81,0x93,0x2a,0xe9,
  0x73,0x43,0x79,0x42,0x55,0x62,0x23,0xc5,0xc3,0xd3,0xa,0x3f,0xa1,0x25,0x5,0xd5,
  0x39,0x7b,0x7a,0x23,0xf6,0x91,0x8d,0x7b,0x49,0x55,0xa3,0x3,0xce,0x6a,0x82,0xf1,
  0x45,0x16,0xfd,0x4c,0xcd,0xa6,0x72,0x4c,0x59,0x7e,0xff,0xa1,0x32,0x10,0x16,0xb,
  0xbe,0x62,0xeb,0x5c,0xd,0x3b,0xd,0xcf,0xc2,0x13,0xd2,0xa5,0x3c,0x3a,0x49,0x94,
  0xbb,0xd2,0x1d,0x1b,0x72,0x49,0x3d,0x51,0x2a,0xa7,0x4f,0x2d,0x90,0x9e,0x1e,0xda,
  0x40,0x2a,0xdb,0xea,0xf6,0x84,0xf6,0xae,0x3e,0xb7,0xbc,0x88,0x2e,0x45,0x6e,0x22,
  0x3b,0x87,0x42,0x9d,0x22,0x28,0xac,0xef,0x78,0x2f,0xbe,0xca,0x3b,0x32,0x2c,0x4b,
  0x5e,0x6a,0x66,0x94,0xf1,0xd2,0xd2,0xd2,0xd5,0x45,0x70,0x33,0xc4,0x90,0x45,0x91,
  0x9f,0x6a,0x7c,0xdd,0x57,0x65,0xcf,0xad,0xd8,0x98,0xce,0x96,0x2,0x1f,0x48,0xf5,
  0x1,0x19,0x40,0x6d,0xb9,0x82,0x9a,0xb4,0x9e,0xeb,0x67,0x88,0x1f,0x77,0x20,0x5e,
  0x17,0xa2,0x3b,0x46,0xaf,0xa3,0xfe,0x13,0x22,0x6b,0x50,0xc3,0xa0,0x2c,0xe4,0xf1,
  0x59,0x74,0x78,0x3a,0xd9,0x92,0x15,0x1d,0x13,0x49,0x21,0x73,0xd9,0x56,0xe9,0x96,
  0x14,0x5a,0x68,0x8b,0x97,0xa2,0xad,0xc2,0xe0,0xf0,0x40,0xb3,0xaf,0x3a,0xdf,0x27,
  0x5b,0x6a,0xe0,0x1b,0xd1,0x92,0xc6,0xe0,0xe3,0xce,0xf0,0x61,0x43,0x4,0x1f,0x91,
  0xe2,0xd3,0xdf,0xb3,0xc4,0x6c,0xc8,0xe7,0x11,0x51,0x20,0x53,0xb,0x31,0x74,0xa9,
  0x1d,0xc0,0xf7,0x27,0x37,0xff,0x1,0x58,0x74,0x31,0x5d,
  
};

static const unsigned char qt_resource_name[] = {
  // kxmlgui5
  0x0,0x8,
  0xf,0x42,0xe5,0x85,
  0x0,0x6b,
  0x0,0x78,0x0,0x6d,0x0,0x6c,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x35,
    // kwrite
  0x0,0x6,
  0x7,0x2e,0x90,0xa5,
  0x0,0x6b,
  0x0,0x77,0x0,0x72,0x0,0x69,0x0,0x74,0x0,0x65,
    // kwriteui.rc
  0x0,0xb,
  0xa,0x2e,0x97,0x83,
  0x0,0x6b,
  0x0,0x77,0x0,0x72,0x0,0x69,0x0,0x74,0x0,0x65,0x0,0x75,0x0,0x69,0x0,0x2e,0x0,0x72,0x0,0x63,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/kxmlgui5
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
  // :/kxmlgui5/kwrite
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
  // :/kxmlgui5/kwrite/kwriteui.rc
  0x0,0x0,0x0,0x28,0x0,0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_kwrite)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_kwrite)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kwrite)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kwrite)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_kwrite)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kwrite)(); }
   } dummy;
}

==> kate-debuginfo-17.08.3-1.tar.xz: usr/src/debug/kate-17.08.3-1/kwrite/qrc_kwrite.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/kate/kate-17.08.3-1.i686/src/kate-17.08.3/kwrite/data/kwriteui.rc
  0x0,0x0,0x2,0x7c,
  0x0,
  0x0,0xa,0x3e,0x78,0x9c,0x9d,0x56,0x4d,0x8f,0x9b,0x30,0x10,0xbd,0xef,0xaf,0x70,
  0x39,0xf4,0xc6,0xd2,0x95,0x2a,0xb5,0x6a,0x48,0x56,0x6d,0x37,0xdb,0xbd,0x44,0x5d,
  0x29,0xd9,0x4a,0x7b,0x42,0xe,0x4c,0x12,0x2b,0x60,0xbb,0xb6,0x49,0x56,0xfd,0xf5,
  0x1d,0x1b,0x92,0x10,0x60,0x81,0xe4,0x6,0xe3,0xf7,0xde,0x8c,0xe7,0xc3,0x76,0x78,
  0xff,0x96,0xa5,0x64,0x7,0x4a,0x33,0xc1,0xc7,0xde,0xdd,0xed,0x27,0x8f,0x0,0x8f,
  0x45,0xc2,0xf8,0x7a,0xec,0xbd,0x2c,0x1e,0xfd,0xaf,0xde,0xfd,0xe4,0x26,0xfc,0xf0,
  0xf0,0xfb,0xe7,0xe2,0xf5,0x79,0x4a,0xb6,0x92,0x2a,0xb3,0xce,0x19,0x99,0xbf,0xce,
  0x17,0xd3,0x19,0xf1,0xe,0x86,0xdb,0xc4,0x24,0x1e,0x22,0x8f,0x0,0x4e,0x33,0x18,
  0x7b,0xdb,0xbd,0x62,0x6,0xbc,0x8a,0x8b,0x2f,0x88,0x22,0x24,0x9c,0x1,0xcf,0x7f,
  0x50,0x65,0xbf,0xcb,0xbf,0x92,0xb1,0x62,0x29,0xe2,0xb9,0x98,0x81,0x5a,0xe3,0xef,
  0x9d,0x57,0x40,0x10,0x64,0xe0,0xcd,0x4c,0x3e,0xd2,0x4c,0x8e,0x1e,0x11,0x13,0x6,
  0xee,0xff,0xb0,0xf8,0x3d,0x36,0xa8,0x5f,0xd1,0x88,0x38,0xec,0xbd,0xe0,0xb8,0x3e,
  0x7,0xc,0x8c,0x1a,0xa1,0x82,0xe,0x8a,0x90,0xc0,0xbd,0x3e,0x40,0xa4,0x20,0x6,
  0x6e,0xba,0xb5,0x1f,0x60,0xc5,0x38,0xfc,0x52,0x22,0x97,0x25,0x5f,0xd3,0x1d,0x44,
  0x99,0xdd,0x94,0x47,0xa8,0x44,0x9d,0xe4,0xcc,0x76,0xa1,0x9a,0x2,0xcc,0xa8,0xa9,
  0xeb,0x9d,0x59,0xbb,0xe8,0x52,0x31,0xde,0x60,0x57,0x8d,0x17,0x26,0x2e,0x4e,0x85,
  0xee,0xf6,0xe8,0x10,0x75,0x8f,0x55,0xe3,0x85,0x1e,0xff,0xe6,0xec,0x58,0x82,0x30,
  0xb0,0xfd,0xd3,0x6c,0x25,0x48,0x10,0xd3,0xd3,0x4a,0x53,0xc4,0xd4,0x5a,0xa9,0x19,
  0xbc,0x15,0x8a,0x72,0x9e,0x88,0xeb,0x8a,0xe5,0xe8,0x92,0x6a,0x73,0x65,0xb1,0x1d,
  0x5f,0x43,0xa,0xf1,0xa0,0xf2,0xbc,0x23,0x80,0xc6,0x64,0x8,0xdd,0x65,0xab,0x27,
  0xb3,0x3b,0x86,0xc3,0xd5,0x93,0xd9,0x3f,0x88,0xe9,0x1a,0x52,0xab,0x61,0x87,0x34,
  0x72,0x62,0x17,0xee,0xc8,0x91,0x71,0x1a,0x11,0x88,0x8a,0xba,0xaf,0x13,0x8c,0x10,
  0xa9,0xee,0xb,0x78,0x61,0x41,0xbd,0xbd,0xe0,0xa4,0xfa,0x5d,0x57,0x72,0x58,0x89,
  0x43,0x83,0x31,0x78,0xb4,0xea,0x36,0xf7,0xf3,0x72,0xad,0x16,0x81,0x93,0x2a,0xe9,
  0x73,0x43,0x79,0x42,0x55,0x62,0x23,0xc5,0xc3,0xd3,0xa,0x3f,0xa1,0x25,0x5,0xd5,
  0x39,0x7b,0x7a,0x23,0xf6,0x91,0x8d,0x7b,0x49,0x55,0xa3,0x3,0xce,0x6a,0x82,0xf1,
  0x45,0x16,0xfd,0x4c,0xcd,0xa6,0x72,0x4c,0x59,0x7e,0xff,0xa1,0x32,0x10,0x16,0xb,
  0xbe,0x62,0xeb,0x5c,0xd,0x3b,0xd,0xcf,0xc2,0x13,0xd2,0xa5,0x3c,0x3a,0x49,0x94,
  0xbb,0xd2,0x1d,0x1b,0x72,0x49,0x3d,0x51,0x2a,0xa7,0x4f,0x2d,0x90,0x9e,0x1e,0xda,
  0x40,0x2a,0xdb,0xea,0xf6,0x84,0xf6,0xae,0x3e,0xb7,0xbc,0x88,0x2e,0x45,0x6e,0x22,
  0x3b,0x87,0x42,0x9d,0x22,0x28,0xac,0xef,0x78,0x2f,0xbe,0xca,0x3b,0x32,0x2c,0x4b,
  0x5e,0x6a,0x66,0x94,0xf1,0xd2,0xd2,0xd2,0xd5,0x45,0x70,0x33,0xc4,0x90,0x45,0x91,
  0x9f,0x6a,0x7c,0xdd,0x57,0x65,0xcf,0xad,0xd8,0x98,0xce,0x96,0x2,0x1f,0x48,0xf5,
  0x1,0x19,0x40,0x6d,0xb9,0x82,0x9a,0xb4,0x9e,0xeb,0x67,0x88,0x1f,0x77,0x20,0x5e,
  0x17,0xa2,0x3b,0x46,0xaf,0xa3,0xfe,0x13,0x22,0x6b,0x50,0xc3,0xa0,0x2c,0xe4,0xf1,
  0x59,0x74,0x78,0x3a,0xd9,0x92,0x15,0x1d,0x13,0x49,0x21,0x73,0xd9,0x56,0xe9,0x96,
  0x14,0x5a,0x68,0x8b,0x97,0xa2,0xad,0xc2,0xe0,0xf0,0x40,0xb3,0xaf,0x3a,0xdf,0x27,
  0x5b,0x6a,0xe0,0x1b,0xd1,0x92,0xc6,0xe0,0xe3,0xce,0xf0,0x61,0x43,0x4,0x1f,0x91,
  0xe2,0xd3,0xdf,0xb3,0xc4,0x6c,0xc8,0xe7,0x11,0x51,0x20,0x53,0xb,0x31,0x74,0xa9,
  0x1d,0xc0,0xf7,0x27,0x37,0xff,0x1,0x58,0x74,0x31,0x5d,
  
};

static const unsigned char qt_resource_name[] = {
  // kxmlgui5
  0x0,0x8,
  0xf,0x42,0xe5,0x85,
  0x0,0x6b,
  0x0,0x78,0x0,0x6d,0x0,0x6c,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x35,
    // kwrite
  0x0,0x6,
  0x7,0x2e,0x90,0xa5,
  0x0,0x6b,
  0x0,0x77,0x0,0x72,0x0,0x69,0x0,0x74,0x0,0x65,
    // kwriteui.rc
  0x0,0xb,
  0xa,0x2e,0x97,0x83,
  0x0,0x6b,
  0x0,0x77,0x0,0x72,0x0,0x69,0x0,0x74,0x0,0x65,0x0,0x75,0x0,0x69,0x0,0x2e,0x0,0x72,0x0,0x63,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/kxmlgui5
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/kxmlgui5/kwrite
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/kxmlgui5/kwrite/kwriteui.rc
  0x0,0x0,0x0,0x28,0x0,0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5f,0x89,0xa1,0xb8,0x70,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_kwrite)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_kwrite)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kwrite)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kwrite)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_kwrite)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kwrite)(); }
   } dummy;
}
